******************************************************************************
*** "Variable Rationalität im demographischen Handeln. Religiosität,**********
*** Kosten und Nutzen von Kindern und die Entscheidung zur Familiengründung" *
*** Datenaufbereitung und Analysen *******************************************
*** Datengrundlage: pairfam (www.pairfam.de, release 7.0) ********************
******************************************************************************

clear all
set maxvar 5100
version 14
set more off

*************************
*** Variablen Welle 1 ***
*************************

use "c:\daten\anchor1.dta", clear

* Religiosität: Typologie grob 

gen rel_miss = 0 
replace rel_miss = 1 if sd30 == -2 | sd30 == -1 | sd31 == -2 | sd31 == -1 | (sd30 > 3 & sd30 < 7) 

gen klos = 0 if rel_miss == 0  
replace klos = 1 if sd30 == 7 

gen inaktiv = 0 if rel_miss == 0   
replace inaktiv = 1 if (sd30 > -1 & sd30 < 7) & (sd31 == 5 | sd31 == 6) & rel_miss == 0 

gen aktiv = 0 if rel_miss == 0  
replace aktiv = 1 if (sd30 > -1 & sd30 < 7) & (sd31 > -1 & sd31 < 5) & rel_miss == 0

tab1 klos inaktiv aktiv 

* Religiosität: Typologie fein 

gen kath_akt = 0 if rel_miss == 0 
replace kath_akt = 1 if sd30 == 1 & sd31 > -1 & sd31 < 5

gen evang_akt = 0 if rel_miss == 0 
replace evang_akt = 1 if sd30 == 2 & sd31 > -1 & sd31 < 5

gen musl_akt = 0 if rel_miss == 0
replace musl_akt = 1 if sd30 == 3 & sd31 > -1 & sd31 < 5

tab1 kath_akt evang_akt musl_akt


* Values of Children 

recode bce2i1-bce2i10 (-2=.) (7=.) 

factor bce2i1-bce2i5, mineigen(1) pcf
rotate, normalize

alpha bce2i1-bce2i5, item /* Alpha = .61 */

egen miss_pvoc = rowmiss(bce2i1-bce2i5)

egen pvoc1 = rowmean(bce2i1-bce2i5) if miss_pvoc < 3

factor bce2i6-bce2i10, mineigen(1) pcf
rotate, normalize

alpha bce2i6-bce2i10, item /* Alpha = .74 */

egen miss_nvoc = rowmiss(bce2i6-bce2i10)

egen nvoc1 = rowmean(bce2i6-bce2i10) if miss_nvoc < 3

sum nvoc1 pvoc1
corr nvoc1 pvoc1 /* corr = -.11 */ 


* Kontrollvariablen, Filtern, Zwischenspeichern

recode val1i3-val1i6 (-2=.) (-1=.) 

factor val1i3 val1i5 val1i6, mineigen(1) pcf
rotate, normalize

alpha val1i3 val1i5 val1i6, item /* Alpha = .52 */

egen miss_trad = rowmiss(val1i3 val1i5 val1i6)

egen trad1 = rowmean(val1i3 val1i5 val1i6) if miss_trad < 2

sum trad1

gen filter_1 = 1 
replace filter_1 = 0 if homosex == 1 | pregnant == 1 | nkids > 0 | pnkidsbioalv > 0
tab filter_1
keep if filter_1 == 1

rename age age1 
rename ethni ethni1 
rename migstatus migstatus1
rename relstat relstat1
rename yeduc yeduc1
rename enrol enrol1
rename penrol penrol1
rename east east1 
rename infertile infert1
rename lfs lfs1
rename plfs plfs1

keep id klos inaktiv aktiv kath_akt evang_akt musl_akt pvoc1 nvoc1 trad1 sex_gen ///
age1 ethni1 migstatus1 relstat1 yeduc1 enrol1 penrol1 east1 infert1 lfs1 plfs1

save "c:\daten\var_wave1.dta", replace


*************************
*** Variablen Welle 2 ***
*************************

use "c:\daten\anchor2.dta", clear

* Values of Children 

recode bce2i1-bce2i10 (-2=.) (7=.) 

factor bce2i1-bce2i5, mineigen(1) pcf
rotate, normalize

alpha bce2i1-bce2i5, item /* Alpha = .64 */

egen miss_pvoc = rowmiss(bce2i1-bce2i5)

egen pvoc2 = rowmean(bce2i1-bce2i5) if miss_pvoc < 3

factor bce2i6-bce2i10, mineigen(1) pcf
rotate, normalize

alpha bce2i6-bce2i10, item /* Alpha = .76 */

egen miss_nvoc = rowmiss(bce2i6-bce2i10)

egen nvoc2 = rowmean(bce2i6-bce2i10) if miss_nvoc < 3

sum nvoc2 pvoc2
corr nvoc2 pvoc2 /* corr = -.14 */ 


* Status, Kontrollvariablen, Zwischenspeichern

egen birth_2 = anycount(crn3k1-crn3k7), values(-1,-2,1,2,3)
recode birth_2 (1/3=1) 
replace birth_2 = 1 if pregnant == 1
tab birth_2

rename age age2
rename ethni ethni2 
rename migstatus migstatus2
rename relstat relstat2
rename yeduc yeduc2
rename enrol enrol2
rename penrol penrol2
rename east east2 
rename infertile infert2 
rename lfs lfs2
rename plfs plfs2

keep id birth_2 pvoc2 nvoc2 age2 ethni2 migstatus2 relstat2 yeduc2 enrol2 penrol2 ///
east2 infert2 lfs2 plfs2

save "c:\daten\var_wave2.dta", replace


*************************
*** Variablen Welle 3 ***
*************************

use "c:\daten\anchor3.dta", clear

* Status, Kontrollvariablen, Zwischenspeichern

recode val1i3-val1i6 (-2=.) (-1=.) 

factor val1i3 val1i5 val1i6, mineigen(1) pcf
rotate, normalize

alpha val1i3 val1i5 val1i6, item /* Alpha = .54 */

egen miss_trad = rowmiss(val1i3 val1i5 val1i6)

egen trad3 = rowmean(val1i3 val1i5 val1i6) if miss_trad < 2

sum trad3


egen birth_3 = anycount(crn3k1-crn3k6), values(-1,-2,1,2,3)
recode birth_3 (1/3=1) 
replace birth_3 = 1 if pregnant == 1
tab birth_3 

rename age age3
rename ethni ethni3 
rename migstatus migstatus3
rename relstat relstat3
rename yeduc yeduc3
rename enrol enrol3
rename penrol penrol3
rename east east3 
rename infertile infert3 
rename lfs lfs3
rename plfs plfs3

keep id birth_3 trad3 age3 ethni3 migstatus3 relstat3 yeduc3 enrol3 penrol3 east3 infert3 ///
lfs3 plfs3

save "c:\daten\var_wave3.dta", replace


*************************
*** Variablen Welle 4 ***
*************************

use "c:\daten\anchor4.dta", clear

* Values of Children 

recode bce2i1-bce2i10 (-2=.) (7=.) 

factor bce2i1-bce2i5, mineigen(1) pcf
rotate, normalize

alpha bce2i1-bce2i5, item /* Alpha = .63 */

egen miss_pvoc = rowmiss(bce2i1-bce2i5)

egen pvoc4 = rowmean(bce2i1-bce2i5) if miss_pvoc < 3

factor bce2i6-bce2i10, mineigen(1) pcf
rotate, normalize

alpha bce2i6-bce2i10, item /* Alpha = .76 */

egen miss_nvoc = rowmiss(bce2i6-bce2i10)

egen nvoc4 = rowmean(bce2i6-bce2i10) if miss_nvoc < 3

sum nvoc4 pvoc4
corr nvoc4 pvoc4 /* corr = -.11 */ 


* Status, Kontrollvariablen, Zwischenspeichern

egen birth_4 = anycount(crn3k1-crn3k7), values(-1,-2,1,2,3)
recode birth_4 (1/3=1) 
replace birth_4 = 1 if pregnant == 1
tab birth_4 

rename age age4
rename ethni ethni4 
rename migstatus migstatus4
rename relstat relstat4
rename yeduc yeduc4
rename enrol enrol4
rename penrol penrol4
rename east east4 
rename infertile infert4 
rename lfs lfs4
rename plfs plfs4

keep id birth_4 pvoc4 nvoc4 age4 ethni4 migstatus4 relstat4 yeduc4 enrol4 penrol4 east4 ///
infert4 lfs4 plfs4 

save "c:\daten\var_wave4.dta", replace


*************************
*** Variablen Welle 5 ***
*************************

use "c:\daten\anchor5.dta", clear

* Religiosität: Typologie grob 

gen rel_miss = 0 
replace rel_miss = 1 if sd30 == -2 | sd30 == -1 | sd31 == -2 | sd31 == -1 | (sd30 > 3 & sd30 < 7) 

gen klos5 = 0 if rel_miss == 0  
replace klos5 = 1 if sd30 == 7 

gen inaktiv5 = 0 if rel_miss == 0   
replace inaktiv5 = 1 if (sd30 > -1 & sd30 < 7) & (sd31 == 5 | sd31 == 6) & rel_miss == 0 

gen aktiv5 = 0 if rel_miss == 0  
replace aktiv5 = 1 if (sd30 > -1 & sd30 < 7) & (sd31 > -1 & sd31 < 5) & rel_miss == 0

tab1 klos5 inaktiv5 aktiv5 

* Religiosität: Typologie fein 

gen kath_akt5 = 0 if rel_miss == 0 
replace kath_akt5 = 1 if sd30 == 1 & sd31 > -1 & sd31 < 5

gen evang_akt5 = 0 if rel_miss == 0 
replace evang_akt5 = 1 if sd30 == 2 & sd31 > -1 & sd31 < 5

gen musl_akt5 = 0 if rel_miss == 0
replace musl_akt5 = 1 if sd30 == 3 & sd31 > -1 & sd31 < 5

tab1 kath_akt5 evang_akt5 musl_akt5


* Status, Kontrollvariablen, Zwischenspeichern

recode val1i3-val1i6 (-2=.) (-1=.) 

factor val1i3 val1i5 val1i6, mineigen(1) pcf
rotate, normalize

alpha val1i3 val1i5 val1i6, item /* Alpha = .53 */

egen miss_trad = rowmiss(val1i3 val1i5 val1i6)

egen trad5 = rowmean(val1i3 val1i5 val1i6) if miss_trad < 2

sum trad5


egen birth_5 = anycount(crn3k1-crn3k5), values(-1,-2,1,2,3)
recode birth_5 (1/3=1) 
replace birth_5 = 1 if pregnant == 1
tab birth_5 

rename age age5
rename ethni ethni5 
rename migstatus migstatus5
rename relstat relstat5
rename yeduc yeduc5
rename enrol enrol5
rename penrol penrol5
rename east east5 
rename infertile infert5 
rename lfs lfs5
rename plfs plfs5

keep id birth_5 klos5 inaktiv5 aktiv5 kath_akt5 evang_akt5 musl_akt5 trad5 ///
age5 ethni5 migstatus5 relstat5 yeduc5 enrol5 penrol5 east5 infert5 lfs5 plfs5

save "c:\daten\var_wave5.dta", replace


*************************
*** Variablen Welle 6 ***
*************************

use "c:\daten\anchor6.dta", clear

* Values of Children 

recode bce2i1-bce2i10 (-2=.) (7=.) 

factor bce2i1-bce2i5, mineigen(1) pcf
rotate, normalize

alpha bce2i1-bce2i5, item /* Alpha = .66 */

egen miss_pvoc = rowmiss(bce2i1-bce2i5)

egen pvoc6 = rowmean(bce2i1-bce2i5) if miss_pvoc < 3

factor bce2i6-bce2i10, mineigen(1) pcf
rotate, normalize

alpha bce2i6-bce2i10, item /* Alpha = .80 */

egen miss_nvoc = rowmiss(bce2i6-bce2i10)

egen nvoc6 = rowmean(bce2i6-bce2i10) if miss_nvoc < 3

sum nvoc6 pvoc6
corr nvoc6 pvoc6 /* corr = -.05 */ 


* Status, Kontrollvariablen, Zwischenspeichern

egen birth_6 = anycount(crn3k1-crn3k6), values(-1,-2,1,2,3)
recode birth_6 (1/3=1) 
replace birth_6 = 1 if pregnant == 1
tab birth_6

rename age age6
rename ethni ethni6 
rename migstatus migstatus6
rename relstat relstat6
rename yeduc yeduc6
rename enrol enrol6
rename penrol penrol6
rename east east6 
rename infertile infert6 
rename lfs lfs6
rename plfs plfs6

keep id birth_6 pvoc6 nvoc6 age6 ethni6 migstatus6 relstat6 yeduc6 enrol6 penrol6 ///
east6 infert6 lfs6 plfs6

save "c:\daten\var_wave6.dta", replace


*************************
*** Variablen Welle 7 ***
*************************

use "c:\daten\anchor7.dta", clear

* Status 

egen birth_7 = anycount(crn3k1-crn3k7), values(-1,-2,1,2,3)
recode birth_7 (1/3=1) 
replace birth_7 = 1 if pregnant == 1
tab birth_7

keep id birth_7

save "c:\daten\var_wave7.dta", replace


*************
*** Merge ***
*************

use "c:\daten\var_wave1.dta", clear

merge 1:1 id using "c:\daten\var_wave2.dta", keep(match master) 

drop _merge 

merge 1:1 id using "c:\daten\var_wave3.dta", keep(match master)

drop _merge

merge 1:1 id using "c:\daten\var_wave4.dta", keep(match master)

drop _merge

merge 1:1 id using "c:\daten\var_wave5.dta", keep(match master)

drop _merge

merge 1:1 id using "c:\daten\var_wave6.dta", keep(match master)

drop _merge

merge 1:1 id using "c:\daten\var_wave7.dta", keep(match master)

drop _merge


**************************************
*** Long-Format, Datenaufbereitung ***
**************************************

gen status1 = 0 if age1 < .
replace status1 = 1 if birth_2 == 1

gen status2 = 0 if age2 < . & status1 == 0 & birth_3 == 0 
replace status2 = 1 if status1 == 0 & birth_3 == 1

gen status3 = 0 if age3 < . & status1 == 0 & status2 == 0 & birth_4 == 0
replace status3 = 1 if status2 == 0 & birth_4 == 1

gen status4 = 0 if age4 < . & status1 == 0 & status2 == 0 & status3 == 0 & birth_5 == 0
replace status4 = 1 if status3 == 0 & birth_5 == 1

gen status5 = 0 if age5 < . & status1 == 0 & status2 == 0 & status3 == 0 & status4 == 0 ///
& birth_6 == 0
replace status5 = 1 if status4 == 0 & birth_6 == 1

gen status6 = 0 if age6 < . & status1 == 0 & status2 == 0 & status3 == 0 & status4 == 0 ///
& status5 == 0 & birth_7 == 0
replace status6 = 1 if status5 == 0 & birth_7 == 1


rename klos klos1 
rename inaktiv inaktiv1 
rename aktiv aktiv1
rename kath_akt kath_akt1
rename evang_akt evang_akt1
rename musl_akt musl_akt1
gen klos2 = klos1 
gen klos3 = klos1 
gen klos4 = klos1 
gen klos6 = klos5
gen inaktiv2 = inaktiv1 
gen inaktiv3 = inaktiv1
gen inaktiv4 = inaktiv1 
gen inaktiv6 = inaktiv5
gen aktiv2 = aktiv1
gen aktiv3 = aktiv1
gen aktiv4 = aktiv1
gen aktiv6 = aktiv5
gen kath_akt2 = kath_akt1
gen kath_akt3 = kath_akt1
gen kath_akt4 = kath_akt1
gen kath_akt6 = kath_akt5
gen evang_akt2 = evang_akt1
gen evang_akt3 = evang_akt1
gen evang_akt4 = evang_akt1
gen evang_akt6 = evang_akt5
gen musl_akt2 = musl_akt1
gen musl_akt3 = musl_akt1
gen musl_akt4 = musl_akt1
gen musl_akt6 = musl_akt5

gen pvoc3 = pvoc2 
gen pvoc5 = pvoc4
gen nvoc3 = nvoc2 
gen nvoc5 = nvoc4

gen trad2 = trad1 
gen trad4 = trad3 
gen trad6 = trad5

reshape long age ethni migstatus relstat enrol penrol yeduc east ///
status klos inaktiv aktiv kath_akt evang_akt musl_akt pvoc nvoc trad infert lfs plfs, i(id) j(wave)

keep if status < . & age < .
drop birth_2 birth_3 birth_4 birth_5 birth_6 birth_7 

recode relstat (1=1) (6=1) (9=1) (-7=.) (else=0), gen(single) 
recode relstat (2=1) (5=1) (7=1) (-7=.) (else=0), gen(lat)
recode relstat (3=1) (8=1) (-7=.) (else=0), gen(nel) 
recode relstat (4=1) (-7=.) (else=0), gen(marr) 

recode migstatus (1=0) (2/3=1) (-7=.)

recode enrol (-7=.) (0=0) (1/19=1)
recode penrol (-7=.) (-3=0) (0=0) (1/19=1)

recode ethni (1=0) (2/5=1), gen(mig2)

recode yeduc (-7=.) (0=.)

recode east (-7=.) 

recode sex_gen (1=1) (2=0) (-4=.), gen(male)

gen lfs_m = lfs if male == 1 
replace lfs_m = plfs if male == 0 
gen lfs_f = lfs if male == 0 
replace lfs_f = plfs if male == 1 

gen mb = 0 
replace mb = 1 if (lfs_m == 9 | lfs_m == 12) & (lfs_f > -3 & lfs_f < 9) 
gen hinzu = 0 
replace hinzu = 1 if (lfs_m == 9 | lfs_m == 12) & lfs_f == 10
gen egali = 0 
replace egali = 1 if ((lfs_m == 9 | lfs_m == 12) & (lfs_f == 9 | lfs_f == 12)) | (lfs_m == 10 & lfs_f == 10) 
gen anti = 0 
replace anti = 1 if (lfs_f == 9 | lfs_f == 12) & (lfs_m > -3 & lfs_m < 9) 
gen nw = 0 
replace nw = 1 if (lfs_m > -3 & lfs_m < 9) & (lfs_f > -3 & lfs_f < 9)
gen sonst = 0 
replace sonst = 1 if mb == 0 & hinzu == 0 & egali == 0 & anti == 0 & nw == 0 & lfs > -3 & plfs > -3 

impute yeduc age enrol east single lat nel mig2 male inaktiv kath_akt evang_akt musl_akt, generate(yeduc2)
replace yeduc2 = 8 if age == 14 & yeduc2 > 8
replace yeduc2 = 9 if age == 15 & yeduc2 > 9

gen agez = age - 22.8
gen ageq = agez*agez

gen a1 = agez*aktiv
gen a2 = ageq*aktiv
gen a3 = agez*inaktiv 
gen a4 = ageq*inaktiv
gen a5 = agez*kath_akt
gen a6 = ageq*kath_akt
gen a7 = agez*evang_akt
gen a8 = ageq*evang_akt

gen yeduxm = yeduc2*male
gen eastxm = east*marr 

gen pvoc_c = pvoc-3.53
gen nvoc_c = nvoc-2.53

gen pvxinakt = pvoc_c*inaktiv 
gen pvxakt = pvoc_c*aktiv 
gen nvxinakt = nvoc_c*inaktiv 
gen nvxakt = nvoc_c*aktiv

gen pvxkath = pvoc_c*kath_akt
gen pvxevang = pvoc_c*evang_akt 
gen nvxkath = nvoc_c*kath_akt
gen nvxevang = nvoc_c*evang_akt 
gen pvxmusl = pvoc_c*musl_akt
gen nvxmusl = nvoc_c*musl_akt


*****************************************************************
*** Zeitdiskrete EDA, Test der Interaktionseffekte mit inteff ***
*****************************************************************

* ssc install inteff

egen miss = rowmiss(agez ageq male mig2 east yeduc2 yeduxm mb hinzu egali anti ///
nw sonst lat nel marr eastxm trad inaktiv kath_akt evang_akt musl_akt pvoc nvoc)

egen miss2 = rowmiss(agez ageq male mig2 east yeduc2 yeduxm lat nel marr eastxm trad ///
inaktiv kath_akt evang_akt pvoc nvoc)

logit status evang_akt pvoc_c pvxevang agez ageq a1-a4 male east yeduc2 yeduxm trad lat nel marr w1-w5 mig2 enrol ///
kath_akt inaktiv pvxkath pvxinakt if musl_akt == 0

inteff status pvoc_c evang_akt pvxevang agez ageq a1-a4 male east yeduc2 yeduxm trad lat nel marr w1-w5 mig2 enrol ///
kath_akt inaktiv pvxkath pvxinakt if musl_akt == 0
* -1.76

logit status nvoc_c kath_akt nvxkath agez ageq a1-a4 male east yeduc2 yeduxm lat nel marr trad w1-w5 mig2 enrol ///
evang_akt inaktiv nvxevang nvxinakt if musl_akt == 0

inteff status nvoc_c kath_akt  nvxkath agez ageq a1-a4 male east yeduc2 yeduxm lat nel marr trad w1-w5 mig2 enrol ///
evang_akt inaktiv nvxevang nvxinakt if musl_akt == 0
* 1.77


*************************
*** Interaktionsplots ***
*************************

gen ageq2 = age*age

* Nutzen

logit status c.evang_akt##c.pvoc_c c.kath_akt##c.pvoc_c c.inaktiv##c.pvoc_c ///
c.age##c.age i.wave male east lat nel marr trad mig2 yeduc2 enrol ///
c.yeduc2##c.male c.evang_akt##c.age c.evang_akt##c.age##c.age ///
c.kath_akt##c.age##c.age c.inaktiv##c.age##c.age if musl_akt == 0 

margins, at(age=(14(2)40) pvoc_c=(-0.63 0.63) evang_akt=(0 1))

marginsplot, xtitle(Alter (Frau)) ///
plot1opts(lpattern(dash)) bydimension(evang_akt, label("Referenz" ///
"Aktive Evangelisten")) ///
plot(, label("geringer VOC (M - 1 SD)""hoher VOC (M + 1 SD)")) ///
ytitle("P(Erstgeburt|Altersjahr j)"" ") scheme(s1mono) ///
saving("c:\daten\nvoc.gph", replace)

* Kosten 

logit status c.evang_akt##c.nvoc_c c.kath_akt##c.nvoc_c c.inaktiv##c.nvoc_c ///
c.age##c.age i.wave male east lat nel marr trad mig2 yeduc2 enrol ///
c.yeduc2##c.male c.evang_akt##c.age c.kath_akt##c.age##c.age ///
c.evang_akt##c.age##c.age c.inaktiv##c.age##c.age if musl_akt == 0 

margins, at(age=(14(2)40) nvoc_c=(-0.76 0.76) kath_akt=(0 1))

marginsplot, xtitle(Alter (Frau)) ///
plot1opts(lpattern(dash)) bydimension(kath_akt, label("Referenz" ///
"Aktive Katholiken")) ///
plot(, label("geringe Kosten (M - 1 SD)""hohe Kosten (M + 1 SD)")) ///
ytitle("P(Erstgeburt|Altersjahr j)"" ") scheme(s1mono) ///
saving("c:\daten\pvoc.gph", replace)


*****************************************************
*** Zeitdiskrete EDA: Mediationsmodelle mit Mplus ***
*****************************************************

drop if musl_akt == 1

keep id status evang_akt kath_akt inaktiv nvoc_c pvoc_c agez ageq a1-a4 male east yeduc2 yeduxm trad lat nel marr w1-w5 mig2 enrol

order id status evang_akt kath_akt inaktiv nvoc_c pvoc_c agez ageq a1-a4 male east yeduc2 yeduxm trad lat nel marr w1-w5 mig2 enrol

recode _all (. = -99) 

outfile _all using "c:\daten\pairfam_mplus.dat", nolabel noquote replace 


***********************************
*** MPLUS Syntax (Beispiel VOC) ***
***********************************
/* 

  Title:    Mediationsmodell "Kindernutzen", Abbildung 1
  Data:     File is pairfam_mplus.dat; 
            LISTWISE = ON;  
  Variable: NAMES ARE id status evang_akt kath_akt inaktiv nvoc_c pvoc_c 
            agez ageq a1-a4 male east yeduc2 yeduxm trad lat nel marr w1-w5 mig2 enrol; 
            USEVARIABLES ARE status evang_akt kath_akt inaktiv pvoc_c agez 
            ageq a1-a4 male east yeduc2 yeduxm trad lat nel marr w1-w5 mig2 enrol;
            CATEGORICAL = status; 
            CLUSTER is id;
            MISSING IS ALL (-99); 
  Analysis: TYPE = COMPLEX; 
            ESTIMATOR = WLSMV; 
  Model:    status ON evang_akt kath_akt inaktiv pvoc_c agez ageq a1-a4 
            male east yeduc2 yeduxm trad lat nel marr w1-w5 mig2 enrol; 
            pvoc_c ON evang_akt kath_akt inaktiv agez ageq a1-a4 
            male east yeduc2 yeduxm trad lat nel marr w1-w5 mig2 enrol; 
            Model indirect: status IND evang_akt;    
                            status IND kath_akt; 
                            status IND inaktiv;    
  OUTPUT:   STANDARDIZED;
  
  